
# Slot: derives from


holds between two distinct material entities, the new entity and the old entity, in which the new entity begins to exist when the old entity ceases to exist, and the new entity inherits the significant portion of the matter of the old entity

URI: [biolink:derives_from](https://w3id.org/biolink/vocab/derives_from)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [is metabolite of](is_metabolite_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
|  | | samples |
| **Exact Mappings:** | | RO:0001000 |
|  | | FMA:derives_from |
|  | | OBO:doid#derives_from |
| **Narrow Mappings:** | | CHEBI:has_functional_parent |
|  | | SNOMED:has_specimen_source_topography |

